@@ -8,7 +8,7 @@
  * See the file "COPYING" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * @(#) $Id: scanner-smi.h,v 1.4 1999/05/31 11:58:34 strauss Exp $
+ * @(#) $Id: scanner-smi.h 973 2000-07-17 09:34:36Z strauss $
  */
 
 #ifndef _SCANNER_SMI_H
@@ -20,11 +20,6 @@
 
 #define YY_NO_UNPUT
 
-
-
-/* we need a reentrant parser, so yylex gets an argument */
-#define YY_DECL int yylex YY_PROTO((YYSTYPE *lvalp, void *parser))
-
 extern char *yytext;
 extern int yyleng;
 
